@@ -1,8 +1,8 @@
 /*
-  $Id: Tagger.cxx 15061 2012-08-08 08:47:53Z sloot $
+  $Id: Tagger.cxx 15567 2013-01-07 14:47:12Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Mbt3/src/Tagger.cxx $
 
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -1349,7 +1349,7 @@ namespace Tagger {
   
   bool TaggerClass::readsettings( string& fname ){
     ifstream setfile( fname.c_str(), ios::in);
-    if(setfile.bad()){
+    if( !setfile ){
       return false;
     }
     char SetBuffer[512];
@@ -1602,7 +1602,7 @@ namespace Tagger {
   void TaggerClass::manifest( ){
     // present yourself to the user
     //
-    LOG << "mbt " << VERSION << " (c) ILK and CLiPS 1998 - 2012." << endl
+    LOG << "mbt " << VERSION << " (c) ILK and CLiPS 1998 - 2013." << endl
 	<< "Memory Based Tagger " << endl
 	<< "Tilburg University" << endl
 	<< "CLiPS Computational Linguistics Group, University of Antwerp"
@@ -1964,7 +1964,7 @@ namespace Tagger {
     // 
     // present yourself to the user
     //
-    cerr << "mbtg " << VERSION << " (c) ILK and CLiPS 1998 - 2012." << endl
+    cerr << "mbtg " << VERSION << " (c) ILK and CLiPS 1998 - 2013." << endl
 	 << "Memory Based Tagger Generator" << endl
 	 << "Induction of Linguistic Knowledge Research Group,"
 	 << "Tilburg University" << endl
